# Q_Learning_O_Run
**用于Q-learning的学习,内含MDP环境和Q-learning决策大脑**

代码是根据莫凡Q-leaning教学视频修改而来

👍 在这感谢莫凡的工作！！！👍 

附莫凡Q-learing学习网址：
https://mofanpy.com/tutorials/machine-learning/reinforcement-learning/intro-q-learning/

## 安装

```shell
pip install Q-Learning-O-Run
```

## 使用
**main.py是使用示例**
1. 项目文件下运行
   ```shell
   python ./tests/test.py
   ``` 
## 学习
> 请看__init__.py和同级的py文件，注释详细

